@@ -246,7 +246,7 @@ sphinx_gallery_conf = {
     'gallery_dirs': os.path.join('generated', 'gallery'),
     'matplotlib_animations': True,
     # Comes from the theme.
-    "default_thumb_file": os.path.join(html_static_path[0], "img", "sunpy_icon_128x128.png"),
+    "default_thumb_file": png_icon,
     'abort_on_example_error': False,
     'plot_gallery': 'True',
     'remove_config_comments': True,
