@@ -34,7 +34,6 @@ class EUIMap(GenericMap):
     def __init__(self, data, header, **kwargs):
         super().__init__(data, header, **kwargs)
         self._nickname = self.detector
-        self.plot_settings['cmap'] = self._get_cmap_name()
         self.plot_settings['norm'] = ImageNormalize(
             stretch=source_stretch(self.meta, LinearStretch()), clip=False)
 
@@ -58,6 +57,14 @@ class EUIMap(GenericMap):
         timesys = self.meta.get('timesys')
         return parse_time(t, scale=timesys.lower())
 
+    @property
+    def waveunit(self):
+        # EUI JP2000 files do not have the WAVEUNIT key in the metadata.
+        # However, the FITS files do.
+        # The EUI metadata spec says the WAVELNTH key is always expressed
+        # in Angstroms so we assume this if the WAVEUNIT is missing.
+        return super().waveunit or u.Angstrom
+
     @property
     def _supported_observer_coordinates(self):
         return [(('hcix_obs', 'hciy_obs', 'hciz_obs'),
