@@ -96,6 +96,7 @@ def test_peek_limb_aia171(aia171_test_map):
 def test_draw_grid_aia171(aia171_test_map):
     aia171_test_map.plot()
     aia171_test_map.draw_grid(grid_spacing=(30, 40) * u.deg)
+    aia171_test_map.draw_grid(system='carrington', color='blue')
 
 
 @figure_test
@@ -168,13 +169,6 @@ def test_quadrangle_aia17_pix_top_right_different_axes(aia171_test_map):
                                     top_right=(80, 90)*u.pix, edgecolor='cyan')
 
 
-@figure_test
-def test_quadrangle_aia17_pix_top_right_different_axes(aia171_test_map):
-    aia171_test_map.rotate(30*u.deg).plot()
-    aia171_test_map.draw_quadrangle(bottom_left=(50, 50)*u.pix,
-                                    top_right=(80, 90)*u.pix, edgecolor='cyan')
-
-
 @figure_test
 def test_plot_masked_aia171(aia171_test_map_with_mask):
     aia171_test_map_with_mask.plot()
@@ -264,8 +258,8 @@ def test_heliographic_quadrangle_top_right(heliographic_test_map):
     heliographic_test_map.draw_quadrangle(bottom_left, top_right=top_right, edgecolor='cyan')
 
 
-# See https://github.com/sunpy/sunpy/issues/4294 to track this warning. Ideally
-# it should not be filtered, and the cause of it fixed.
+# This warning filter can be removed once we depend on Astropy 5.0+.
+# See https://github.com/sunpy/sunpy/issues/4294
 @pytest.mark.filterwarnings(r'ignore:Numpy has detected that you \(may be\) writing to an array with\noverlapping memory')
 @figure_test
 def test_heliographic_grid_annotations(heliographic_test_map):
