@@ -12,6 +12,7 @@ from pathlib import Path
 from textwrap import dedent
 from collections.abc import Sequence
 
+import numpy as np
 import parfive
 
 from astropy.table import Table
@@ -183,7 +184,11 @@ class UnifiedResponse(Sequence):
         for block in self:
             ret += f"{len(block)} Results from the {block.client.__class__.__name__}:\n"
             if block.client.info_url is not None:
-                ret += f'Source: {block.client.info_url}\n\n'
+                ret += f'Source: {block.client.info_url}\n'
+            size = block.total_size()
+            if np.isfinite(size):
+                ret += f'Total estimated size: {size}\n'
+            ret += '\n'
             lines = repr(block).split('\n')
             ret += '\n'.join(lines[1:])
             ret += '\n\n'
@@ -310,7 +315,11 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         # client generated results, we drop the empty VSO results for tidiness.
         # This is because the VSO _can_handle_query is very broad because we
         # don't know the full list of supported values we can search for (yet).
-        results = [r for r in results if not isinstance(r, vso.VSOQueryResponseTable) or len(r) > 0]
+        if len(results) > 1:
+            vso_results = list(filter(lambda r: isinstance(r, vso.VSOQueryResponseTable), results))
+            for vres in vso_results:
+                if len(vres) == 0:
+                    results.remove(vres)
 
         return UnifiedResponse(*results)
 
@@ -483,7 +492,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         return results
 
     def __repr__(self):
-        return object.__repr__(self) + "\n" + self._print_clients(visible_entries=15)
+        return object.__repr__(self) + "\n" + self._print_clients()
 
     def __str__(self):
         """
@@ -495,9 +504,9 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         """
         This enables the "pretty" printing of the Fido Clients with html.
         """
-        return self._print_clients(visible_entries=15, html=True)
+        return self._print_clients(html=True)
 
-    def _print_clients(self, html=False, visible_entries=None):
+    def _print_clients(self, html=False, visible_entries=-1):
         width = -1 if html else get_width()
 
         t = Table(names=["Client", "Description"], dtype=["U80", "U120"])
